@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2017-2019 Vaclav Slavik
+ *  Copyright (C) 2017-2020 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -159,7 +159,7 @@ public:
             cmdline += " " + extraFlags;
 
         if (!ExecuteGettext(cmdline))
-            return "";
+            throw ExtractionException(ExtractionError::Unspecified);
 
         return outfile;
     }
