@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2000-2019 Vaclav Slavik
+ *  Copyright (C) 2000-2020 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -146,6 +146,10 @@ long DoExecuteGettext(const wxString& cmdline_, wxArrayString& gstderr)
     process->Redirect();
 
     long retcode = wxExecute(cmdline, wxEXEC_BLOCK | wxEXEC_NODISABLE | wxEXEC_NOEVENTS, process.get(), &env);
+    if (retcode != 0)
+    {
+        wxLogTrace("poedit.execute", "  execution of command failed with exit code %d: %s", (int)retcode, cmdline.c_str());
+    }
 
 	wxInputStream *std_err = process->GetErrorStream();
     if ( std_err && !ReadOutput(*std_err, gstderr) )
